Name:           gforth
Version:        0.7.3
Release:        %mkrel 12
Summary:        Fast and portable implementation of the ANS Forth language

Group:          Development/Other
License:        GPLv3+
URL:            https://www.gnu.org/software/gforth/
Source:         https://www.complang.tuwien.ac.at/forth/gforth/gforth-%{version}.tar.gz
Patch0:         gforth-0.7.0-shebang.patch
# s390 build fix from Debian (https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=544827)
Patch1:         gforth-0.7.0-compile-fix.patch
Patch2:         gforth-libtool-build.patch
Patch3:         configure-assumptions.patch
Patch4:         gforth-configure-c99.patch
BuildRequires:  m4  libltdl-devel
BuildRequires:  libffi-devel
BuildRequires:  libtool
Recommends:     libtool

%description
Gforth is a fast and portable implementation of the ANS Forth
language. It works nicely with the Emacs editor, offers some nice
features such as input completion and history, backtraces, a
decompiler and a powerful locals facility, and it even has a
manual. Gforth combines traditional implementation techniques with
newer techniques for portability and performance performance: its
inner interpreter is direct threaded with several optimizations, but
you can also use a traditional-style indirect threaded interpreter.

%define emacs_sitestart_d  %{_datadir}/emacs/site-lisp/site-start.d
%define emacs_site_lisp  %{_datadir}/emacs/site-lisp
%define xemacs_sitestart_d %{_datadir}/xemacs/site-packages/lisp/site-start.d
%define xemacs_site_lisp %{_datadir}/xemacs/site-packages/lisp
%define gforth_datadir %{_datadir}/gforth


%prep
%autosetup -p1
# Fix path to gforth-ditc binary
sed -i 's@/lib/@/%{_lib}/@' gforthmi.in

iconv -f latin1 -t utf8 AUTHORS > AUTHORS.new
mv -f AUTHORS.new AUTHORS

%build
CFLAGS="${RPM_OPT_FLAGS} `pkg-config libffi --cflags`" %configure
# %%{_smp_mflags} breaks the build
%{__make}

%install
%make_install
cat > $RPM_BUILD_ROOT%{gforth_datadir}/site-forth/siteinit.fs <<EOF
\ If you change this file, you need to recompile gforth.fi
EOF
rm -f $RPM_BUILD_ROOT/%{_infodir}/dir
mkdir -p $RPM_BUILD_ROOT%{gforth_datadir}/emacs
cp -f gforth.el $RPM_BUILD_ROOT%{gforth_datadir}/emacs
cat > $RPM_BUILD_ROOT%{gforth_datadir}/emacs/gforth-init.el <<EOF
(autoload 'forth-mode "gforth" "Forth mode" t)
(autoload 'run-forth "gforth" "Run Forth" t)
(add-to-list 'auto-mode-alist '("\\.fs$" . forth-mode))
EOF
for i in httpd.fs filedump.fs sieve.fs
do
   chmod 0755 $RPM_BUILD_ROOT%{_datadir}/gforth/%{version}/$i
done
for dir in %{emacs_sitestart_d} %{xemacs_sitestart_d}; do
    install -dm 755 $RPM_BUILD_ROOT$dir
    touch $RPM_BUILD_ROOT$dir/gforth-init.el
done
for dir in %{emacs_site_lisp} %{xemacs_site_lisp}; do
    install -dm 755 $RPM_BUILD_ROOT$dir
    touch $RPM_BUILD_ROOT$dir/gforth.el
done

find $RPM_BUILD_ROOT -name TAGS | xargs rm -f


%triggerin -- emacs-common
if [ -d %{emacs_sitestart_d} ]; then
  ln -sf %{gforth_datadir}/emacs/gforth-init.el %{emacs_sitestart_d} || :
  ln -sf %{gforth_datadir}/emacs/gforth.el %{emacs_site_lisp} || :
fi

%triggerin -- xemacs-common
if [ -d %{xemacs_sitestart_d} ]; then
  ln -sf %{gforth_datadir}/emacs/gforth-init.el %{xemacs_sitestart_d} || :
  ln -sf %{gforth_datadir}/emacs/gforth.el %{xemacs_site_lisp} || :
fi


%triggerun -- emacs-common
if [ $2 = 0 ]; then
  rm -f %{emacs_sitestart_d}/gforth-init.el* || :
  rm -f %{emacs_site_lisp}/gforth.el* || :
fi


%triggerun -- xemacs-common
if [ $2 = 0 ]; then
  rm -f %{xemacs_sitestart_d}/gforth-init.el* || :
  rm -f %{xemacs_site_lisp}/gforth.el* || :
fi


%files
%doc COPYING COPYING.DOC README README.vmgen NEWS NEWS.vmgen AUTHORS BUGS ChangeLog
%{_bindir}/*
%{_infodir}/*
%{_datadir}/gforth
%{_libdir}/gforth
%{_includedir}/gforth
%{_mandir}/man1/*
%ghost %{_datadir}/*emacs




%changelog
* Mon Mar 17 2025 danf <danf> 0.7.3-12.mga10
+ Revision: 2165686
- Fix path in gforthmi (mga#34109)

* Thu Oct 24 2024 ns80 <ns80> 0.7.3-11.mga10
+ Revision: 2111051
- add patches from Fedora to try to fix building with GCC 14

* Wed Mar 16 2022 umeabot <umeabot> 0.7.3-10.mga9
+ Revision: 1794685
- Mageia 9 Mass Rebuild

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.7.3-9.mga9
+ Revision: 1739639
- rebuild for libffi

* Thu Aug 20 2020 ovitters <ovitters> 0.7.3-8.mga8
+ Revision: 1616879
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Sun Jun 28 2020 joequant <joequant> 0.7.3-7.mga8
+ Revision: 1599869
- remove arm workaround
+ ovitters <ovitters>
- rebuild for new ffi

* Tue Feb 11 2020 umeabot <umeabot> 0.7.3-5.mga8
+ Revision: 1488914
- Mageia 8 Mass Rebuild
- Mageia 7 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
+ shlomif <shlomif>
- Rebuild due to age

* Thu Jun 07 2018 wally <wally> 0.7.3-2.mga7
+ Revision: 1235223
- fix build on aarch64

* Sun Feb 25 2018 shlomif <shlomif> 0.7.3-1.mga7
+ Revision: 1205118
- Importing based on Fedora

